//
//  TCGBPush.h
//  Gamebase
//
//  Created by NHN on 2016. 5. 31..
//  © NHN Corp. All rights reserved.
//

#import <Foundation/Foundation.h>

@class TCGBError;

extern NSString* const kTCGBPushEnabledKeyname;          // keyname of pushEnabled property
extern NSString* const kTCGBPushADAgreementKeyname;      // keyname of ADAgreement property
extern NSString* const kTCGBPushADAgreementNightKeyname; // keyname of ADAgreementNight property
extern NSString* const kTCGBPushDisplayLanguageCodeKeyname;  // keyname of displayLanguageCode property

/** The TCGBPushConfiguration class configures the behavior of TCGBPush.
 */
@interface TCGBLegacyPushConfiguration : NSObject

/**---------------------------------------------------------------------------------------
 * @name Properties
 *  ---------------------------------------------------------------------------------------
 */

/**
 Enable push
 */
@property (nonatomic, assign) BOOL pushEnabled;

/**
 Agreement of getting advertising push
 */
@property (nonatomic, assign) BOOL ADAgreement;

/**
 Agreement of getting advertising push at night
 */
@property (nonatomic, assign) BOOL ADAgreementNight;

/**
 Setting language of Push Message
 */
@property (nonatomic, strong) NSString* displayLanguageCode;

/**---------------------------------------------------------------------------------------
 * @name Initialization
 *  ---------------------------------------------------------------------------------------
 */

/**
 Creates a TCGBPushConfiguration instance with several properties.
 
 @param enable whether push enable or not.
 @param ADAgree `YES` if user agree on advertising push notification.
 @param ADAgreeNight `YES` if user agree on getting advertising push notification at night.
 */
+ (TCGBLegacyPushConfiguration *)pushConfigurationWithPushEnable:(BOOL)enable ADAgreement:(BOOL)ADAgree ADAgreementNight:(BOOL)ADAgreeNight;

/**
 Creates a TCGBPushConfiguration instance with several properties.
 
 @param enable whether push enable or not.
 @param ADAgree `YES` if user agree on advertising push notification.
 @param ADAgreeNight `YES` if user agree on getting advertising push notification at night.
 @param displayLanguage set language code for Push. (kTCPushKeyLanguage in TOAST Push SDK)
 */
+ (TCGBLegacyPushConfiguration *)pushConfigurationWithPushEnable:(BOOL)enable ADAgreement:(BOOL)ADAgree ADAgreementNight:(BOOL)ADAgreeNight displayLanguage:(NSString *)displayLanguage;

/**
 Creates a TCGBPushConfiguration instance with several properties.
 @param jsonString In this string, there should be `pushEnabled`, `adAgreement`, `adAgreementNight` keys in the json formatted string.
 */
+ (TCGBLegacyPushConfiguration *)pushConfigurationWithJSONString:(NSString *)jsonString;

- (NSString *)JSONString;

- (NSString *)JSONPrettyString;

@end

/** The TCGBPush class provides registering push token API to ToastCloud Push Server and querying push token API.
 */
@interface TCGBLegacyPush : NSObject

/**
 Register push token to ToastCloud Push Server.
 
 @param configuration The configuration which has pushEnabled, ADAgreement and AdAgreementNight.
 @param completion callback
 
 @see TCGBPushConfiguration
 @since Added 1.4.0.
 @deprecated As of release 2.5.0, use registerTokenWithCompletion: method instead.
 */
+ (void)registerPushWithPushConfiguration:(TCGBLegacyPushConfiguration *)configuration completion:(void(^)(TCGBError *error))completion DEPRECATED_MSG_ATTRIBUTE("Use TCGBPush instead.");
;

/**
 Query push token to ToastCloud Push Server.
 
 @param completion callback, this callback has TCGBPushConfiguration information.
 
 @see TCGBPushConfiguration
 @since Added 1.4.0.
 @deprecated As of release 2.5.0, use queryTokenInfoWithCompletion: method instead.
 */
+ (void)queryPushWithCompletion:(void(^)(TCGBLegacyPushConfiguration *configuration, TCGBError *error))completion DEPRECATED_MSG_ATTRIBUTE("Use TCGBPush instead.");
;

/**
 Set SandboxMode.
 
 @param isSandbox `YES` if application is on the sandbox mode.
 @since Added 1.4.0.
 @deprecated As of release 2.5.0, use setSandbox: method instead.
 */
+ (void)setSandboxMode:(BOOL)isSandbox DEPRECATED_MSG_ATTRIBUTE("Use TCGBPush instead.");
;

@end
